@@ -5,10 +5,7 @@ import typing as t
 from collections import defaultdict
 from itertools import starmap
 
-from crackerjack.services.cache import CrackerjackCache
-from crackerjack.services.debug import get_ai_agent_debugger
-
-from .base import (
+from crackerjack.agents.base import (
     AgentContext,
     FixResult,
     Issue,
@@ -16,24 +13,27 @@ from .base import (
     SubAgent,
     agent_registry,
 )
-from .tracker import get_agent_tracker
+from crackerjack.agents.error_middleware import agent_error_boundary
+from crackerjack.agents.tracker import get_agent_tracker
+from crackerjack.services.cache import CrackerjackCache
+from crackerjack.services.debug import get_ai_agent_debugger
 
-# Static mapping for O(1) agent lookup by issue type
-ISSUE_TYPE_TO_AGENTS = {
+ISSUE_TYPE_TO_AGENTS: dict[IssueType, list[str]] = {
+    IssueType.FORMATTING: ["FormattingAgent"],
+    IssueType.TYPE_ERROR: ["TestCreationAgent", "RefactoringAgent"],
+    IssueType.SECURITY: ["SecurityAgent"],
+    IssueType.TEST_FAILURE: ["TestSpecialistAgent", "TestCreationAgent"],
+    IssueType.IMPORT_ERROR: ["ImportOptimizationAgent"],
     IssueType.COMPLEXITY: ["RefactoringAgent"],
     IssueType.DEAD_CODE: ["RefactoringAgent", "ImportOptimizationAgent"],
-    IssueType.SECURITY: ["SecurityAgent"],
-    IssueType.PERFORMANCE: ["PerformanceAgent", "RefactoringAgent"],
-    IssueType.TEST_FAILURE: ["TestCreationAgent", "TestSpecialistAgent"],
-    IssueType.TYPE_ERROR: ["TestCreationAgent", "RefactoringAgent"],
-    IssueType.FORMATTING: ["FormattingAgent", "ImportOptimizationAgent"],
+    IssueType.DEPENDENCY: ["ImportOptimizationAgent"],
+    IssueType.DRY_VIOLATION: ["DRYAgent"],
+    IssueType.PERFORMANCE: ["PerformanceAgent"],
     IssueType.DOCUMENTATION: ["DocumentationAgent"],
-    IssueType.DRY_VIOLATION: ["DRYAgent", "RefactoringAgent"],
-    IssueType.IMPORT_ERROR: ["ImportOptimizationAgent", "RefactoringAgent"],
-    IssueType.COVERAGE_IMPROVEMENT: ["TestCreationAgent", "TestSpecialistAgent"],
-    IssueType.TEST_ORGANIZATION: ["TestSpecialistAgent", "TestCreationAgent"],
-    IssueType.DEPENDENCY: ["RefactoringAgent"],
+    IssueType.TEST_ORGANIZATION: ["TestSpecialistAgent"],
+    IssueType.COVERAGE_IMPROVEMENT: ["TestCreationAgent"],
     IssueType.REGEX_VALIDATION: ["SecurityAgent", "RefactoringAgent"],
+    IssueType.SEMANTIC_CONTEXT: ["SemanticAgent", "ArchitectAgent"],
 }
 
 
@@ -292,39 +292,27 @@ class AgentCoordinator:
             metadata={"issue_type": issue.type.value, "severity": issue.severity.value},
         )
 
-        try:
-            # Use cached analysis for better performance
-            result = await self._cached_analyze_and_fix(agent, issue)
-            if result.success:
-                self.logger.info(f"{agent.name} successfully fixed issue")
-            else:
-                self.logger.warning(f"{agent.name} failed to fix issue")
+        result = await self._execute_agent(agent, issue)
+        if result.success:
+            self.logger.info(f"{agent.name} successfully fixed issue")
+        else:
+            self.logger.warning(f"{agent.name} failed to fix issue")
 
-            self.tracker.track_agent_complete(agent.name, result)
+        self.tracker.track_agent_complete(agent.name, result)
 
-            self.debugger.log_agent_activity(
-                agent_name=agent.name,
-                activity="processing_completed",
-                issue_id=issue.id,
-                confidence=result.confidence,
-                result={
-                    "success": result.success,
-                    "remaining_issues": len(result.remaining_issues),
-                },
-                metadata={"fix_applied": result.success},
-            )
+        self.debugger.log_agent_activity(
+            agent_name=agent.name,
+            activity="processing_completed",
+            issue_id=issue.id,
+            confidence=result.confidence,
+            result={
+                "success": result.success,
+                "remaining_issues": len(result.remaining_issues),
+            },
+            metadata={"fix_applied": result.success},
+        )
 
-            return result
-        except Exception as e:
-            self.logger.exception(f"{agent.name} threw exception: {e}")
-            error_result = FixResult(
-                success=False,
-                confidence=0.0,
-                remaining_issues=[f"{agent.name} failed with exception: {e}"],
-            )
-
-            self.tracker.track_agent_complete(agent.name, error_result)
-            return error_result
+        return result
 
     def _group_issues_by_type(
         self,
@@ -347,6 +335,11 @@ class AgentCoordinator:
         issue_hash = self._create_issue_hash(issue)
         return f"{agent_name}:{issue_hash}"
 
+    @agent_error_boundary
+    async def _execute_agent(self, agent: SubAgent, issue: Issue) -> FixResult:
+        """Execute agent analysis with centralized error handling."""
+        return await self._cached_analyze_and_fix(agent, issue)
+
     async def _cached_analyze_and_fix(self, agent: SubAgent, issue: Issue) -> FixResult:
         """Analyze and fix issue with intelligent caching."""
         cache_key = self._get_cache_key(agent.name, issue)
@@ -450,12 +443,15 @@ class AgentCoordinator:
 
         try:
             plan = await architect.plan_before_action(primary_issue)
-            plan = self._enrich_architectural_plan(plan, all_issues)
+            # Ensure plan is properly typed as dict[str, Any]
+            if not isinstance(plan, dict):
+                plan = {"strategy": "default", "confidence": 0.5}
+            enriched_plan = self._enrich_architectural_plan(plan, all_issues)
 
             self.logger.info(
-                f"Created architectural plan: {plan.get('strategy', 'unknown')}"
+                f"Created architectural plan: {enriched_plan.get('strategy', 'unknown')}"
             )
-            return plan  # type: ignore[no-any-return]
+            return enriched_plan
 
         except Exception as e:
             self.logger.exception(f"Failed to create architectural plan: {e}")
