@@ -88,6 +88,9 @@ class Options(BaseModel):
     skip_hooks: bool = False
     fast: bool = False
     comp: bool = False
+    fast_iteration: bool = False  # Phase 10.2.4: Skip comprehensive hooks
+    tool: str | None = None  # Phase 10.2.4: Run only specific tool
+    changed_only: bool = False  # Phase 10.2.4: Run on changed files only
     async_mode: bool = False
     experimental_hooks: bool = False
     enable_pyrefly: bool = False
@@ -124,7 +127,7 @@ class Options(BaseModel):
     unified_dashboard: bool = False
     unified_dashboard_port: int | None = None
     max_iterations: int = 5
-    enterprise_batch: str | None = None
+    advanced_batch: str | None = None
     monitor_dashboard: str | None = None
     coverage_status: bool = False
     coverage_goal: float | None = None
@@ -137,12 +140,25 @@ class Options(BaseModel):
     quick: bool = False
     thorough: bool = False
     clear_cache: bool = False
+
+    # Semantic search options
+    index: str | None = None
+    search: str | None = None
+    semantic_stats: bool = False
+    remove_from_index: str | None = None
     cache_stats: bool = False
 
+    # ACB workflow integration (Phase 4.2 COMPLETE: ACB is now the default)
+    # Use --use-legacy-orchestrator to revert to the old orchestration system
+    use_acb_workflows: bool = True  # ACB workflow engine is now the default
+    use_legacy_orchestrator: bool = False  # Opt-in to legacy orchestrator
+    refresh_cache: bool = False
+
     # Semantic field names (new primary interface)
     strip_code: bool | None = None  # Replaces clean
     run_tests: bool = False  # Replaces test
     ai_fix: bool | None = None  # Replaces ai_agent
+    dry_run: bool = False  # Preview fixes without applying
     full_release: str | None = None  # Replaces all
     show_progress: bool | None = None  # Replaces track_progress
     advanced_monitor: bool | None = None  # Replaces enhanced_monitor
@@ -180,12 +196,10 @@ class Options(BaseModel):
     apply_config_updates: bool = False
     diff_config: str | None = None
     config_interactive: bool = False
-    refresh_cache: bool = False
-
-    # Enterprise features
-    enterprise_optimizer: bool = False
-    enterprise_profile: str | None = None
-    enterprise_report: str | None = None
+    # Advanced features
+    advanced_optimizer: bool = False
+    advanced_profile: str | None = None
+    advanced_report: str | None = None
     mkdocs_integration: bool = False
     mkdocs_serve: bool = False
     mkdocs_theme: str = "material"
@@ -323,8 +337,8 @@ CLI_OPTIONS = {
     "update_precommit": typer.Option(
         False,
         "-u",
-        "--update-precommit",
-        help="Update pre-commit hooks configuration.",
+        "--update-hooks",
+        help="Update hooks configuration.",
     ),
     "verbose": typer.Option(False, "-v", "--verbose", help="Enable verbose output."),
     "debug": typer.Option(False, "--debug", help="Enable debug output."),
@@ -333,8 +347,6 @@ CLI_OPTIONS = {
         "-p",
         "--publish",
         callback=parse_bump_option_with_flag_support,
-        is_flag=False,
-        flag_value="interactive",
         help=(
             "Bump version and publish to PyPI (patch, minor, major, auto). "
             "Use 'interactive' to be prompted for version selection. "
@@ -384,7 +396,7 @@ CLI_OPTIONS = {
         False,
         "-s",
         "--skip-hooks",
-        help="Skip running pre-commit hooks (useful with -t).",
+        help="Skip running hooks (useful with -t).",
     ),
     "fast": typer.Option(
         False,
@@ -399,6 +411,21 @@ CLI_OPTIONS = {
             "complexity analysis)."
         ),
     ),
+    "fast_iteration": typer.Option(
+        False,
+        "--fast-iteration",
+        help="Skip comprehensive hooks during active development (formatters only).",
+    ),
+    "tool": typer.Option(
+        None,
+        "--tool",
+        help="Run only the specified tool (e.g., 'ruff-check', 'zuban').",
+    ),
+    "changed_only": typer.Option(
+        False,
+        "--changed-only",
+        help="Run quality checks only on files changed in git.",
+    ),
     "create_pr": typer.Option(
         False,
         "-r",
@@ -430,7 +457,7 @@ CLI_OPTIONS = {
     "experimental_hooks": typer.Option(
         False,
         "--experimental-hooks",
-        help="Enable experimental pre-commit hooks (includes pyrefly and ty).",
+        help="Enable experimental hooks (includes pyrefly and ty).",
     ),
     "enable_pyrefly": typer.Option(
         False,
@@ -577,9 +604,9 @@ CLI_OPTIONS = {
         help="Port for unified dashboard server (default: 8675).",
     ),
     "max_iterations": typer.Option(
-        5,
+        10,
         "--max-iterations",
-        help="Maximum number of iterations for AI agent auto-fixing workflows (default: 5).",
+        help="Maximum auto-fix iterations (default: 10).",
     ),
     "ai_debug": typer.Option(
         False,
@@ -700,10 +727,17 @@ CLI_OPTIONS = {
         None,
         "--ai-fix",
         help=(
-            "Enable AI-powered automatic fixing of code quality issues "
-            "and test failures."
+            "Enable AI-powered auto-fixing. "
+            "Iteratively fixes code issues using Claude AI. "
+            "Requires ANTHROPIC_API_KEY environment variable. "
+            "Max 10 iterations, stops when all hooks pass."
         ),
     ),
+    "dry_run": typer.Option(
+        False,
+        "--dry-run",
+        help="Preview fixes without modifying files (implies --ai-fix).",
+    ),
     "full_release": typer.Option(
         None,
         "-a",
@@ -847,21 +881,21 @@ CLI_OPTIONS = {
         "--analytics-dashboard",
         help="Output file path for analytics dashboard (HTML format).",
     ),
-    # Enterprise features
-    "enterprise_optimizer": typer.Option(
+    # Advanced features
+    "advanced_optimizer": typer.Option(
         False,
-        "--enterprise-optimizer",
-        help="Enable enterprise-scale optimization engine with resource monitoring and scaling analysis.",
+        "--advanced-optimizer",
+        help="Enable advanced-scale optimization engine with resource monitoring and scaling analysis.",
     ),
-    "enterprise_profile": typer.Option(
+    "advanced_profile": typer.Option(
         None,
-        "--enterprise-profile",
-        help="Enterprise optimization profile: balanced, performance, memory, throughput.",
+        "--advanced-profile",
+        help="Advanced optimization profile: balanced, performance, memory, throughput.",
     ),
-    "enterprise_report": typer.Option(
+    "advanced_report": typer.Option(
         None,
-        "--enterprise-report",
-        help="Output file path for enterprise optimization report (JSON format).",
+        "--advanced-report",
+        help="Output file path for advanced optimization report (JSON format).",
     ),
     "mkdocs_integration": typer.Option(
         False,
@@ -922,7 +956,41 @@ CLI_OPTIONS = {
     "refresh_cache": typer.Option(
         False,
         "--refresh-cache",
-        help="Refresh pre-commit cache to ensure fresh environment.",
+        help="Refresh cache to ensure fresh environment.",
+    ),
+    # ACB workflow integration (Phase 4.2 COMPLETE - ACB is now the default)
+    "use_acb_workflows": typer.Option(
+        True,  # ACB workflows are now the default
+        "--use-acb-workflows",
+        help="[DEFAULT - REDUNDANT] ACB is now always used (kept for compatibility).",
+        hidden=True,  # Hidden since it's redundant (ACB is always the default)
+    ),
+    "use_legacy_orchestrator": typer.Option(
+        False,
+        "--use-legacy-orchestrator/--no-use-legacy-orchestrator",
+        help="Opt out of ACB workflows and use legacy orchestrator (for compatibility).",
+        hidden=False,
+    ),
+    # Semantic search options
+    "index": typer.Option(
+        None,
+        "--index",
+        help="Index a file or directory for semantic search (e.g., --index path/to/file.py).",
+    ),
+    "search": typer.Option(
+        None,
+        "--search",
+        help="Perform semantic search across indexed files (e.g., --search 'similarity calculation').",
+    ),
+    "semantic_stats": typer.Option(
+        False,
+        "--semantic-stats",
+        help="Display statistics about the semantic search index.",
+    ),
+    "remove_from_index": typer.Option(
+        None,
+        "--remove-from-index",
+        help="Remove a file from the semantic search index (e.g., --remove-from-index path/to/file.py).",
     ),
 }
 
@@ -942,6 +1010,9 @@ def create_options(
     skip_hooks: bool,
     fast: bool,
     comp: bool,
+    fast_iteration: bool,
+    tool: str | None,
+    changed_only: bool,
     create_pr: bool,
     async_mode: bool,
     experimental_hooks: bool,
@@ -998,10 +1069,10 @@ def create_options(
     predictive_analytics: bool,
     prediction_periods: int,
     analytics_dashboard: str | None,
-    # Enterprise features
-    enterprise_optimizer: bool,
-    enterprise_profile: str | None,
-    enterprise_report: str | None,
+    # Advanced features
+    advanced_optimizer: bool,
+    advanced_profile: str | None,
+    advanced_report: str | None,
     mkdocs_integration: bool,
     mkdocs_serve: bool,
     mkdocs_theme: str,
@@ -1014,10 +1085,13 @@ def create_options(
     diff_config: str | None,
     config_interactive: bool,
     refresh_cache: bool,
+    use_acb_workflows: bool,
+    use_legacy_orchestrator: bool,
     # New semantic parameters
     strip_code: bool | None = None,
     run_tests: bool = False,
     ai_fix: bool | None = None,
+    dry_run: bool = False,
     full_release: str | None = None,
     show_progress: bool | None = None,
     advanced_monitor: bool | None = None,
@@ -1039,6 +1113,9 @@ def create_options(
         skip_hooks=skip_hooks,
         fast=fast,
         comp=comp,
+        fast_iteration=fast_iteration,
+        tool=tool,
+        changed_only=changed_only,
         create_pr=create_pr,
         async_mode=async_mode,
         experimental_hooks=experimental_hooks,
@@ -1095,10 +1172,10 @@ def create_options(
         predictive_analytics=predictive_analytics,
         prediction_periods=prediction_periods,
         analytics_dashboard=analytics_dashboard,
-        # Enterprise features
-        enterprise_optimizer=enterprise_optimizer,
-        enterprise_profile=enterprise_profile,
-        enterprise_report=enterprise_report,
+        # Advanced features
+        advanced_optimizer=advanced_optimizer,
+        advanced_profile=advanced_profile,
+        advanced_report=advanced_report,
         mkdocs_integration=mkdocs_integration,
         mkdocs_serve=mkdocs_serve,
         mkdocs_theme=mkdocs_theme,
@@ -1111,10 +1188,13 @@ def create_options(
         diff_config=diff_config,
         config_interactive=config_interactive,
         refresh_cache=refresh_cache,
+        use_acb_workflows=use_acb_workflows,
+        use_legacy_orchestrator=use_legacy_orchestrator,
         # New semantic parameters
         strip_code=strip_code,
         run_tests=run_tests,
         ai_fix=ai_fix,
+        dry_run=dry_run,
         full_release=full_release,
         show_progress=show_progress,
         advanced_monitor=advanced_monitor,
