@@ -1,9 +1,10 @@
 import asyncio
-import logging
 import time
 import typing as t
 from pathlib import Path
 
+from acb.depends import Inject, depends
+from acb.logger import Logger
 from rich.console import Console
 
 from crackerjack.agents.base import FixResult, Issue, IssueType, Priority
@@ -15,9 +16,11 @@ from .timeout_manager import TimeoutStrategy, get_timeout_manager
 
 
 class AsyncWorkflowPipeline:
+    @depends.inject
     def __init__(
         self,
-        console: Console,
+        logger: Inject[Logger],
+        console: Inject[Console],
         pkg_path: Path,
         session: SessionCoordinator,
         phases: PhaseCoordinator,
@@ -26,7 +29,7 @@ class AsyncWorkflowPipeline:
         self.pkg_path = pkg_path
         self.session = session
         self.phases = phases
-        self.logger = logging.getLogger("crackerjack.async_pipeline")
+        self.logger = logger
         self.timeout_manager = get_timeout_manager()
         self._active_tasks: list[asyncio.Task[t.Any]] = []
         self.resource_context: t.Any | None = None
@@ -110,7 +113,7 @@ class AsyncWorkflowPipeline:
 
         result = await self.timeout_manager.with_timeout(
             "file_operations",
-            asyncio.to_thread(self.phases.run_cleaning_phase, options),  # type: ignore[arg-type]
+            asyncio.to_thread(self.phases.run_cleaning_phase, options),
             strategy=TimeoutStrategy.RETRY_WITH_BACKOFF,
         )
         return bool(result)
@@ -262,7 +265,7 @@ class AsyncWorkflowPipeline:
     async def _run_fast_hooks_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "fast_hooks",
-            asyncio.to_thread(self.phases.run_fast_hooks_only, options),  # type: ignore[arg-type]
+            asyncio.to_thread(self.phases.run_fast_hooks_only, options),
             strategy=TimeoutStrategy.RETRY_WITH_BACKOFF,
         )
         return bool(result)
@@ -270,7 +273,7 @@ class AsyncWorkflowPipeline:
     async def _run_comprehensive_hooks_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "comprehensive_hooks",
-            asyncio.to_thread(self.phases.run_comprehensive_hooks_only, options),  # type: ignore[arg-type]
+            asyncio.to_thread(self.phases.run_comprehensive_hooks_only, options),
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
         return bool(result)
@@ -278,7 +281,7 @@ class AsyncWorkflowPipeline:
     async def _run_hooks_phase_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "comprehensive_hooks",
-            asyncio.to_thread(self.phases.run_hooks_phase, options),  # type: ignore[arg-type]
+            asyncio.to_thread(self.phases.run_hooks_phase, options),
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
         return bool(result)
@@ -286,7 +289,7 @@ class AsyncWorkflowPipeline:
     async def _run_testing_phase_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "test_execution",
-            asyncio.to_thread(self.phases.run_testing_phase, options),  # type: ignore[arg-type]
+            asyncio.to_thread(self.phases.run_testing_phase, options),
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
         return bool(result)
@@ -507,7 +510,7 @@ class AsyncWorkflowPipeline:
         try:
             hook_results = await self.timeout_manager.with_timeout(
                 "comprehensive_hooks",
-                asyncio.to_thread(self.phases.hook_manager.run_comprehensive_hooks),  # type: ignore[arg-type]
+                asyncio.to_thread(self.phases.hook_manager.run_comprehensive_hooks),
                 strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
             )
 
@@ -573,10 +576,11 @@ class AsyncWorkflowPipeline:
 
     def _create_agent_coordinator(self) -> t.Any:
         from crackerjack.agents.base import AgentContext
-        from crackerjack.agents.coordinator import AgentCoordinator
+        from crackerjack.agents.enhanced_coordinator import create_enhanced_coordinator
 
         context = AgentContext(project_path=self.pkg_path)
-        return AgentCoordinator(context)
+        # Use enhanced coordinator with Claude Code agent integration
+        return create_enhanced_coordinator(context=context, enable_external_agents=True)
 
     def _report_fix_results(self, fix_result: FixResult, iteration: int) -> None:
         if fix_result.success:
@@ -602,24 +606,32 @@ class AsyncWorkflowPipeline:
 
 
 class AsyncWorkflowOrchestrator:
+    @depends.inject
     def __init__(
         self,
-        console: Console | None = None,
+        logger: Inject[Logger],
+        console: Inject[Console],
         pkg_path: Path | None = None,
         dry_run: bool = False,
         web_job_id: str | None = None,
         verbose: bool = False,
         debug: bool = False,
     ) -> None:
-        self.console = console or Console(force_terminal=True)
+        # Initialize console and pkg_path first
+        self.console = console
         self.pkg_path = pkg_path or Path.cwd()
         self.dry_run = dry_run
         self.web_job_id = web_job_id
         self.verbose = verbose
         self.debug = debug
 
-        self._initialize_logging()
+        # Configure ACB dependency injection using native patterns
+        from acb.depends import depends
 
+        # Register core dependencies directly with ACB
+        depends.set(Path, self.pkg_path)
+
+        # Import protocols for retrieving dependencies via ACB
         from crackerjack.models.protocols import (
             ConfigMergeServiceProtocol,
             FileSystemInterface,
@@ -629,48 +641,50 @@ class AsyncWorkflowOrchestrator:
             TestManagerProtocol,
         )
 
-        from .enhanced_container import create_enhanced_container
+        # Setup services with ACB DI (reuse from WorkflowOrchestrator)
+        from .workflow_orchestrator import WorkflowOrchestrator
 
-        self.container = create_enhanced_container(
-            console=self.console,
-            pkg_path=self.pkg_path,
-            dry_run=self.dry_run,
-        )
+        # Use a temporary orchestrator instance just for service setup
+        temp_orch = WorkflowOrchestrator.__new__(WorkflowOrchestrator)
+        temp_orch.console = self.console
+        temp_orch.pkg_path = self.pkg_path
+        temp_orch.verbose = self.verbose
+        temp_orch._setup_acb_services()
 
+        self._initialize_logging()
+
+        self.logger = logger
+
+        # Create coordinators - dependencies retrieved via ACB's depends.get_sync()
         self.session = SessionCoordinator(self.console, self.pkg_path, self.web_job_id)
         self.phases = PhaseCoordinator(
             console=self.console,
             pkg_path=self.pkg_path,
             session=self.session,
-            filesystem=self.container.get(FileSystemInterface),
-            git_service=self.container.get(GitInterface),
-            hook_manager=self.container.get(HookManager),
-            test_manager=self.container.get(TestManagerProtocol),
-            publish_manager=self.container.get(PublishManager),
-            config_merge_service=self.container.get(ConfigMergeServiceProtocol),
+            filesystem=depends.get_sync(FileSystemInterface),
+            git_service=depends.get_sync(GitInterface),
+            hook_manager=depends.get_sync(HookManager),
+            test_manager=depends.get_sync(TestManagerProtocol),
+            publish_manager=depends.get_sync(PublishManager),
+            config_merge_service=depends.get_sync(ConfigMergeServiceProtocol),
         )
 
         self.async_pipeline = AsyncWorkflowPipeline(
-            console=self.console,
             pkg_path=self.pkg_path,
             session=self.session,
             phases=self.phases,
         )
 
-        self.logger = logging.getLogger("crackerjack.async_orchestrator")
-
     def _initialize_logging(self) -> None:
         from crackerjack.services.log_manager import get_log_manager
-        from crackerjack.services.logging import setup_structured_logging
 
         log_manager = get_log_manager()
         session_id = getattr(self, "web_job_id", None) or str(int(time.time()))[:8]
         debug_log_file = log_manager.create_debug_log_file(session_id)
 
         log_level = "DEBUG" if self.debug else "INFO"
-        setup_structured_logging(
-            level=log_level, json_output=False, log_file=debug_log_file
-        )
+        self.logger.set_level(log_level)
+        self.logger.add_file_handler(debug_log_file)
 
     async def run_complete_workflow_async(self, options: OptionsProtocol) -> bool:
         return await self.async_pipeline.run_complete_workflow_async(options)
