@@ -1,18 +1,23 @@
 import subprocess
 from pathlib import Path
 
-from rich.console import Console
-
-from crackerjack.services.logging import get_logger
+from acb.console import Console
+from acb.depends import Inject, depends
+from acb.logger import Logger
 
 
 class AutofixCoordinator:
-    def __init__(self, console: Console, pkg_path: Path) -> None:
+    @depends.inject
+    def __init__(
+        self,
+        console: Inject[Console],
+        pkg_path: Path,
+        logger: Inject[Logger],
+    ) -> None:
         self.console = console
         self.pkg_path = pkg_path
-        self.logger = get_logger("crackerjack.autofix")
-
-        setattr(self.logger, "name", "crackerjack.autofix")
+        # Bind logger context with name for tracing
+        self.logger = logger.bind(logger="crackerjack.autofix")
 
     def apply_autofix_for_hooks(self, mode: str, hook_results: list[object]) -> bool:
         try:
