@@ -148,7 +148,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "id": "uv-lock",
             "name": None,
             "repo": "https://github.com/astral-sh/uv-pre-commit",
-            "rev": "0.8.15",
+            "rev": "0.9.0",
             "tier": 1,
             "time_estimate": 0.5,
             "stages": None,
@@ -174,7 +174,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "stages": None,
             "args": None,
             "files": None,
-            "exclude": r"uv\.lock|pyproject\.toml|tests/.*|docs/.*|.*\.md",
+            "exclude": r"uv\.lock|pyproject\.toml|tests/.*|docs/.*|\.claude/.*|.*\.md",
             "additional_dependencies": None,
             "types_or": None,
             "language": None,
@@ -224,7 +224,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "id": "ruff-check",
             "name": None,
             "repo": "https://github.com/astral-sh/ruff-pre-commit",
-            "rev": "v0.12.12",
+            "rev": "v0.14.0",
             "tier": 2,
             "time_estimate": 1.5,
             "stages": None,
@@ -242,7 +242,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "id": "ruff-format",
             "name": None,
             "repo": "https://github.com/astral-sh/ruff-pre-commit",
-            "rev": "v0.12.12",
+            "rev": "v0.14.0",
             "tier": 2,
             "time_estimate": 1.0,
             "stages": None,
@@ -334,7 +334,7 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "id": "refurb",
             "name": None,
             "repo": "https://github.com/dosisod/refurb",
-            "rev": "v2.1.0",
+            "rev": "v2.2.0",
             "tier": 3,
             "time_estimate": 3.0,
             "stages": ["pre-push", "manual"],
@@ -366,24 +366,6 @@ HOOKS_REGISTRY: dict[str, list[HookMetadata]] = {
             "experimental": False,
             "pass_filenames": False,
         },
-        {
-            "id": "pyright",
-            "name": "pyright-type-checking",
-            "repo": "local",
-            "rev": "",
-            "tier": 3,
-            "time_estimate": 0.25,
-            "stages": ["pre-push", "manual"],
-            "args": [],
-            "files": "^crackerjack/.*\\.py$",
-            "exclude": r"^crackerjack/(mcp|plugins)/.*\.py$|crackerjack/code_cleaner\.py$",
-            "additional_dependencies": None,
-            "types_or": None,
-            "language": "system",
-            "entry": "uv run pyright",
-            "experimental": False,
-            "pass_filenames": None,
-        },
     ],
     "experimental": [],
 }
@@ -465,19 +447,15 @@ class DynamicConfigGenerator:
         )
 
     def _sanitize_package_directory(self, package_directory: str) -> str:
-        """Convert hyphens to underscores in package directory names."""
         return package_directory.replace("-", "_")
 
     def _detect_package_directory(self) -> str:
-        """Detect the package directory name for the current project."""
         from pathlib import Path
 
-        # Check if we're in the crackerjack project itself
         current_dir = Path.cwd()
         if (current_dir / "crackerjack").exists() and (
             current_dir / "pyproject.toml"
         ).exists():
-            # Check if this is actually the crackerjack project
             with suppress(Exception):
                 import tomllib
 
@@ -486,7 +464,6 @@ class DynamicConfigGenerator:
                 if data.get("project", {}).get("name") == "crackerjack":
                     return "crackerjack"
 
-        # Try to read package name from pyproject.toml
         pyproject_path = current_dir / "pyproject.toml"
         if pyproject_path.exists():
             with suppress(Exception):
@@ -497,15 +474,13 @@ class DynamicConfigGenerator:
 
                 if "project" in data and "name" in data["project"]:
                     package_name = str(data["project"]["name"])
-                    # Check if package directory exists
+
                     if (current_dir / package_name).exists():
                         return package_name
 
-        # Fallback to project directory name
         if (current_dir / current_dir.name).exists():
             return current_dir.name
 
-        # Default fallback to current directory name
         return current_dir.name
 
     def _should_include_hook(
@@ -534,21 +509,16 @@ class DynamicConfigGenerator:
         for category_hooks in HOOKS_REGISTRY.values():
             for hook in category_hooks:
                 if self._should_include_hook(hook, config, enabled_experimental):
-                    # Create a copy and update package-specific configurations
                     updated_hook = self._update_hook_for_package(hook.copy())
                     filtered_hooks.append(updated_hook)
 
         return filtered_hooks
 
     def _update_hook_for_package(self, hook: HookMetadata) -> HookMetadata:
-        """Update hook configuration to use the detected package directory."""
-        # Update skylos hook
         if hook["id"] == "skylos" and hook["args"]:
             hook["args"] = [self.package_directory, "--exclude", "tests"]
 
-        # Update zuban hook
         elif hook["id"] == "zuban" and hook["args"]:
-            # Replace the hardcoded "./crackerjack" with the dynamic package directory
             updated_args = []
             for arg in hook["args"]:
                 if arg == "./crackerjack":
@@ -557,7 +527,6 @@ class DynamicConfigGenerator:
                     updated_args.append(arg)
             hook["args"] = updated_args
 
-        # Update other hooks that use hardcoded "crackerjack" patterns
         elif hook["files"] and "crackerjack" in hook["files"]:
             hook["files"] = hook["files"].replace("crackerjack", self.package_directory)
 
@@ -566,20 +535,16 @@ class DynamicConfigGenerator:
                 "crackerjack", self.package_directory
             )
 
-        # Ensure hooks exclude src directories to avoid JavaScript conflicts and tests
         if hook["exclude"]:
-            # Add src exclusion if not present
             if "src/" not in hook["exclude"]:
                 hook["exclude"] = f"{hook['exclude']}|^src/"
         else:
-            # If no exclusion, add both tests and src
             if hook["id"] in (
                 "skylos",
                 "zuban",
                 "bandit",
                 "refurb",
                 "complexipy",
-                "pyright",
             ):
                 hook["exclude"] = r"^tests/|^src/"
             else:
