@@ -1,11 +1,13 @@
 from .async_hook_executor import AsyncHookExecutor
 from .cached_hook_executor import CachedHookExecutor, SmartCacheManager
 from .hook_executor import HookExecutionResult, HookExecutor
+from .progress_hook_executor import ProgressHookExecutor
 
 __all__ = [
     "AsyncHookExecutor",
     "CachedHookExecutor",
     "HookExecutionResult",
     "HookExecutor",
+    "ProgressHookExecutor",
     "SmartCacheManager",
 ]
