@@ -6,8 +6,9 @@ from concurrent.futures import ThreadPoolExecutor, as_completed
 from dataclasses import dataclass
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
 
+from crackerjack.config import get_console_width
 from crackerjack.config.hooks import HookDefinition, HookStrategy, RetryPolicy
 from crackerjack.models.task import HookResult
 from crackerjack.services.security_logger import get_security_logger
@@ -66,7 +67,7 @@ class HookExecutor:
     def execute_strategy(self, strategy: HookStrategy) -> HookExecutionResult:
         start_time = time.time()
 
-        self._print_strategy_header(strategy)
+        # Header is displayed by PhaseCoordinator; suppress here to avoid duplicates
 
         if strategy.parallel and len(strategy.hooks) > 1:
             results = self._execute_parallel(strategy)
@@ -90,20 +91,8 @@ class HookExecutor:
         )
 
     def _print_strategy_header(self, strategy: HookStrategy) -> None:
-        self.console.print("\n" + "-" * 74)
-        if strategy.name == "fast":
-            self.console.print(
-                "[bold bright_cyan]🔍 HOOKS[/bold bright_cyan] [bold bright_white]Running code quality checks[/bold bright_white]",
-            )
-        elif strategy.name == "comprehensive":
-            self.console.print(
-                "[bold bright_cyan]🔍 HOOKS[/bold bright_cyan] [bold bright_white]Running comprehensive quality checks[/bold bright_white]",
-            )
-        else:
-            self.console.print(
-                f"[bold bright_cyan]🔍 HOOKS[/bold bright_cyan] [bold bright_white]Running {strategy.name} hooks[/bold bright_white]",
-            )
-        self.console.print("-" * 74 + "\n")
+        # Intentionally no-op: PhaseCoordinator controls stage headers
+        return None
 
     def _execute_sequential(self, strategy: HookStrategy) -> list[HookResult]:
         results: list[HookResult] = []
@@ -220,16 +209,24 @@ class HookExecutor:
             else:
                 status = "failed"
         else:
-            status = "passed" if result.returncode == 0 else "failed"
+            # Treat some analysis tools as non-blocking when they return 1 to
+            # indicate findings (not execution failure).
+            if hook.name in {"creosote", "complexipy"} and result.returncode == 1:
+                status = "passed"
+            else:
+                status = "passed" if result.returncode == 0 else "failed"
 
         issues_found = self._extract_issues_from_process_output(hook, result, status)
 
+        # Parse hook output to extract file count
+        parsed_output = self._parse_hook_output(result)
+
         return HookResult(
             id=hook.name,
             name=hook.name,
             status=status,
             duration=duration,
-            files_processed=0,
+            files_processed=parsed_output["files_processed"],
             issues_found=issues_found,
             stage=hook.stage.value,
         )
@@ -284,23 +281,46 @@ class HookExecutor:
         result: subprocess.CompletedProcess[str],
     ) -> dict[str, t.Any]:
         output = result.stdout + result.stderr
+
+        # Attempt to extract file count from output
+        files_processed = 0
+
+        # Check for common patterns in hook output
+        if "files" in output.lower():
+            import re
+
+            # Pattern for "N file(s)" in output
+            file_count_patterns = [
+                r"(\d+)\s+files?",  # "5 files" or "1 file"
+                r"Checking\s+(\d+)\s+files?",  # "Checking 5 files"
+                r"Found\s+(\d+)\s+files?",  # "Found 5 files"
+            ]
+            for pattern in file_count_patterns:
+                match = re.search(pattern, output, re.IGNORECASE)
+                if match:
+                    files_processed = int(match.group(1))
+                    break
+
         return {
             "hook_id": None,
             "exit_code": result.returncode,
-            "files_processed": 0,
+            "files_processed": files_processed,
             "issues": [],
             "raw_output": output,
         }
 
     def _display_hook_result(self, result: HookResult) -> None:
+        if self.quiet:
+            return
         status_icon = "✅" if result.status == "passed" else "❌"
 
-        max_width = 70
+        max_width = get_console_width()
+        content_width = max_width - 4  # Adjusted for icon and padding
 
-        if len(result.name) > max_width:
-            line = result.name[: max_width - 3] + "..."
+        if len(result.name) > content_width:
+            line = result.name[: content_width - 3] + "..."
         else:
-            dots_needed = max_width - len(result.name)
+            dots_needed = max(0, content_width - len(result.name))
             line = result.name + ("." * dots_needed)
 
         self.console.print(f"{line} {status_icon}")
