@@ -10,27 +10,26 @@ type checking during pre-commit hooks.
 import sys
 from pathlib import Path
 
+from acb.console import Console
+
 from crackerjack.services.lsp_client import LSPClient
-from rich.console import Console
 
 
-def main() -> int:
+def main(console: Console | None = None) -> int:
     """Main entry point for LSP hook."""
-    console = Console()
-
+    console = console or Console()
     # Get files to check from command line arguments
     files_to_check = sys.argv[1:] if len(sys.argv) > 1 else []
 
     # If no files specified, check project files
     if not files_to_check:
-        files_to_check = _get_project_files(console)
+        files_to_check = _get_project_files()
 
     if not files_to_check:
         console.print("🔍 No Python files to check")
         return 0
 
-    # Initialize LSP client
-    lsp_client = LSPClient(console)
+    lsp_client = LSPClient()
 
     # Check if LSP server is running
     if not lsp_client.is_server_running():
@@ -40,10 +39,10 @@ def main() -> int:
     return _check_files_with_lsp(console, lsp_client, files_to_check)
 
 
-def _get_project_files(console: Console) -> list[str]:
+def _get_project_files() -> list[str]:
     """Get project files to check."""
     project_path = Path.cwd()
-    lsp_client = LSPClient(console)
+    lsp_client = LSPClient()
     return lsp_client.get_project_files(project_path)
 
 
