@@ -5,7 +5,7 @@ import time
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
 from rich.live import Live
 
 from .test_progress import TestProgress
