@@ -3,47 +3,49 @@ import time
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
-
-from crackerjack.models.protocols import CoverageRatchetProtocol, OptionsProtocol
+from acb.config import root_path
+from acb.console import Console
+from acb.depends import Inject, depends
+from crackerjack.models.protocols import CoverageBadgeServiceProtocol, CoverageRatchetProtocol, OptionsProtocol, TestManagerProtocol, ServiceProtocol
+from crackerjack.services.coverage_badge_service import CoverageBadgeService
+from crackerjack.services.lsp_client import LSPClient
 
 from .test_command_builder import TestCommandBuilder
 from .test_executor import TestExecutor
 
 
 class TestManager:
+    @depends.inject
     def __init__(
         self,
-        console: Console,
-        pkg_path: Path,
-        coverage_ratchet: CoverageRatchetProtocol | None = None,
+        console: Inject[Console],
+        coverage_ratchet: Inject[CoverageRatchetProtocol],
+        coverage_badge: Inject[CoverageBadgeServiceProtocol],
+        lsp_client: Inject[LSPClient] | None = None,
     ) -> None:
         self.console = console
-        self.pkg_path = pkg_path
+        # Ensure a concrete pathlib.Path instance to avoid async Path behaviors
+        # and to guarantee sync filesystem operations in this manager.
+        try:
+            self.pkg_path = Path(str(root_path))
+        except Exception:
+            # Fallback in the unlikely event root_path lacks __str__
+            self.pkg_path = Path(root_path)
 
-        self.executor = TestExecutor(console, pkg_path)
-        self.command_builder = TestCommandBuilder(pkg_path)
+        # Ensure downstream components receive a concrete pathlib.Path
+        self.executor = TestExecutor(console, self.pkg_path)
+        self.command_builder = TestCommandBuilder(self.pkg_path)
 
-        if coverage_ratchet is None:
-            from crackerjack.services.coverage_ratchet import CoverageRatchetService
-
-            coverage_ratchet_obj = CoverageRatchetService(pkg_path, console)
-            self.coverage_ratchet: CoverageRatchetProtocol | None = t.cast(
-                CoverageRatchetProtocol, coverage_ratchet_obj
-            )
-        else:
-            self.coverage_ratchet = coverage_ratchet
+        # Services injected via ACB DI
+        self.coverage_ratchet = coverage_ratchet
+        self._coverage_badge_service = coverage_badge
+        self._lsp_client = lsp_client
 
         self._last_test_failures: list[str] = []
         self._progress_callback: t.Callable[[dict[str, t.Any]], None] | None = None
         self.coverage_ratchet_enabled = True
         self.use_lsp_diagnostics = True
 
-        # Initialize coverage badge service
-        from crackerjack.services.coverage_badge_service import CoverageBadgeService
-
-        self._coverage_badge_service = CoverageBadgeService(console, pkg_path)
-
     def set_progress_callback(
         self,
         callback: t.Callable[[dict[str, t.Any]], None] | None,
@@ -128,66 +130,91 @@ class TestManager:
         except Exception:
             return None
 
+    def _get_coverage_from_file(self) -> float | None:
+        """Extract coverage from coverage.json file."""
+        import json
+
+        coverage_json_path = self.pkg_path / "coverage.json"
+        if not coverage_json_path.exists():
+            return None
+
+        try:
+            with coverage_json_path.open() as f:
+                coverage_data = json.load(f)
+
+            # Extract coverage percentage from totals
+            totals = coverage_data.get("totals", {})
+            percent_covered = totals.get("percent_covered", None)
+
+            if percent_covered is not None:
+                return float(percent_covered)
+
+            # Alternative extraction methods for different coverage formats
+            if "percent_covered" in coverage_data:
+                return float(coverage_data["percent_covered"])
+
+            # Check for coverage in files section
+            files = coverage_data.get("files", {})
+            if files:
+                total_lines = 0
+                covered_lines = 0
+                for file_data in files.values():
+                    summary = file_data.get("summary", {})
+                    total_lines += summary.get("num_statements", 0)
+                    covered_lines += summary.get("covered_lines", 0)
+
+                if total_lines > 0:
+                    return (covered_lines / total_lines) * 100
+
+            return None
+
+        except (json.JSONDecodeError, ValueError, KeyError, TypeError):
+            return None
+
+    def _handle_no_ratchet_status(
+        self, direct_coverage: float | None
+    ) -> dict[str, t.Any]:
+        """Handle case when ratchet is not initialized."""
+        if direct_coverage is not None:
+            return {
+                "status": "coverage_available",
+                "coverage_percent": direct_coverage,
+                "message": "Coverage data available from coverage.json",
+                "source": "coverage.json",
+            }
+
+        return {
+            "status": "not_initialized",
+            "coverage_percent": 0.0,
+            "message": "Coverage ratchet not initialized",
+        }
+
+    def _get_final_coverage(
+        self, ratchet_coverage: float, direct_coverage: float | None
+    ) -> float:
+        """Determine final coverage value."""
+        return direct_coverage if direct_coverage is not None else ratchet_coverage
+
     def get_coverage(self) -> dict[str, t.Any]:
         try:
             status = self.coverage_ratchet.get_status_report()
 
             # Check if we have actual coverage data from coverage.json even if ratchet is not initialized
-            coverage_json_path = self.pkg_path / "coverage.json"
-            direct_coverage = None
-
-            if coverage_json_path.exists():
-                try:
-                    import json
-
-                    with coverage_json_path.open() as f:
-                        data = json.load(f)
-                        # Check for totals field first (newer format)
-                        direct_coverage = data.get("totals", {}).get("percent_covered")
-
-                        # If no totals, calculate from files data (standard pytest-cov format)
-                        if direct_coverage is None and "files" in data:
-                            total_statements = 0
-                            total_covered = 0
-
-                            for file_data in data["files"].values():
-                                summary = file_data.get("summary", {})
-                                statements = summary.get("num_statements", 0)
-                                covered = summary.get("covered_lines", 0)
-                                total_statements += statements
-                                total_covered += covered
-
-                            if total_statements > 0:
-                                direct_coverage = (
-                                    total_covered / total_statements
-                                ) * 100
-                except (json.JSONDecodeError, KeyError):
-                    pass  # Fall back to ratchet data
+            direct_coverage = self._get_coverage_from_file()
 
             # If ratchet is not initialized but we have direct coverage data, use it
             if (
                 not status or status.get("status") == "not_initialized"
             ) and direct_coverage is not None:
-                return {
-                    "status": "coverage_available",
-                    "coverage_percent": direct_coverage,
-                    "message": "Coverage data available from coverage.json",
-                    "source": "coverage.json",
-                }
+                return self._handle_no_ratchet_status(direct_coverage)
 
             # If ratchet is not initialized and no direct coverage, return not initialized
             if not status or status.get("status") == "not_initialized":
-                return {
-                    "status": "not_initialized",
-                    "coverage_percent": 0.0,
-                    "message": "Coverage ratchet not initialized",
-                }
+                return self._handle_no_ratchet_status(None)
 
             # Use ratchet data, but prefer direct coverage if available and different
             ratchet_coverage = status.get("current_coverage", 0.0)
-            final_coverage = (
-                direct_coverage if direct_coverage is not None else ratchet_coverage
-            )
+            final_coverage = self._get_final_coverage(ratchet_coverage, direct_coverage)
 
             return {
                 "status": "active",
@@ -215,11 +242,11 @@ class TestManager:
             test_path = self.pkg_path / test_dir
             if test_path.exists() and test_path.is_dir():
                 for test_file_pattern in test_files:
-                    if list[t.Any](test_path.glob(f"**/{test_file_pattern}")):
+                    if list(test_path.glob(f"**/{test_file_pattern}")):
                         return True
 
         for test_file_pattern in test_files:
-            if list[t.Any](self.pkg_path.glob(test_file_pattern)):
+            if list(self.pkg_path.glob(test_file_pattern)):
                 return True
 
         return False
@@ -277,73 +304,64 @@ class TestManager:
 
         return self._handle_ratchet_result(ratchet_result)
 
+    def _attempt_coverage_extraction(self) -> float | None:
+        """Attempt to extract coverage from various sources."""
+        # Primary: Try to extract from coverage.json
+        current_coverage = self._get_coverage_from_file()
+        if current_coverage is not None:
+            return current_coverage
+
+        return None
+
+    def _handle_coverage_extraction_result(
+        self, current_coverage: float | None
+    ) -> float | None:
+        """Handle the result of coverage extraction attempts."""
+        if current_coverage is not None:
+            self.console.print(
+                f"[dim]📊 Coverage extracted from coverage.json: {current_coverage:.2f}%[/dim]"
+            )
+        return current_coverage
+
+    def _get_fallback_coverage(
+        self, ratchet_result: dict[str, t.Any], current_coverage: float | None
+    ) -> float | None:
+        """Get coverage from fallback sources."""
+        # Secondary: Try ratchet result if coverage.json failed
+        if current_coverage is None:
+            current_coverage = self._get_coverage_from_ratchet(ratchet_result)
+            if current_coverage is not None:
+                self.console.print(
+                    f"[dim]📊 Coverage from ratchet result: {current_coverage:.2f}%[/dim]"
+                )
+
+        # Tertiary: Try coverage service, but only accept non-zero values
+        if current_coverage is None:
+            current_coverage = self._get_coverage_from_service()
+            if current_coverage is not None:
+                self.console.print(
+                    f"[dim]📊 Coverage from service fallback: {current_coverage:.2f}%[/dim]"
+                )
+            else:
+                coverage_json_path = self.pkg_path / "coverage.json"
+                if coverage_json_path.exists():
+                    self.console.print(
+                        "[yellow]⚠️[/yellow] Skipping 0.0% fallback when coverage.json exists"
+                    )
+
+        return current_coverage
+
     def _update_coverage_badge(self, ratchet_result: dict[str, t.Any]) -> None:
         """Update coverage badge in README.md if coverage changed."""
         try:
             # Get current coverage directly from coverage.json to ensure freshest data
-            import json
+            current_coverage = self._attempt_coverage_extraction()
+            current_coverage = self._handle_coverage_extraction_result(current_coverage)
 
-            current_coverage = None
-            coverage_json_path = self.pkg_path / "coverage.json"
-
-            # Primary: Try to extract from coverage.json
-            if coverage_json_path.exists():
-                try:
-                    with coverage_json_path.open() as f:
-                        data = json.load(f)
-                        # Check for totals field first (newer format)
-                        current_coverage = data.get("totals", {}).get("percent_covered")
-
-                        # If no totals, calculate from files data (standard pytest-cov format)
-                        if current_coverage is None and "files" in data:
-                            total_statements = 0
-                            total_covered = 0
-
-                            for file_data in data["files"].values():
-                                summary = file_data.get("summary", {})
-                                statements = summary.get("num_statements", 0)
-                                covered = summary.get("covered_lines", 0)
-                                total_statements += statements
-                                total_covered += covered
-
-                            if total_statements > 0:
-                                current_coverage = (
-                                    total_covered / total_statements
-                                ) * 100
-
-                        if current_coverage is not None:
-                            self.console.print(
-                                f"[dim]📊 Coverage extracted from coverage.json: {current_coverage:.2f}%[/dim]"
-                            )
-                except (json.JSONDecodeError, KeyError) as e:
-                    self.console.print(
-                        f"[yellow]⚠️[/yellow] Failed to parse coverage.json: {e}"
-                    )
-
-            # Secondary: Try ratchet result if coverage.json failed
-            if current_coverage is None:
-                current_coverage = ratchet_result.get("current_coverage")
-                if current_coverage is not None:
-                    self.console.print(
-                        f"[dim]📊 Coverage from ratchet result: {current_coverage:.2f}%[/dim]"
-                    )
-
-            # Tertiary: Try coverage service, but only accept non-zero values
-            if current_coverage is None:
-                coverage_info = self.get_coverage()
-                fallback_coverage = coverage_info.get("coverage_percent")
-                # Only use fallback if it's meaningful (>0) or if no coverage.json exists
-                if fallback_coverage and (
-                    fallback_coverage > 0 or not coverage_json_path.exists()
-                ):
-                    current_coverage = fallback_coverage
-                    self.console.print(
-                        f"[dim]📊 Coverage from service fallback: {current_coverage:.2f}%[/dim]"
-                    )
-                else:
-                    self.console.print(
-                        "[yellow]⚠️[/yellow] Skipping 0.0% fallback when coverage.json exists"
-                    )
+            # Get fallback coverage if needed
+            current_coverage = self._get_fallback_coverage(
+                ratchet_result, current_coverage
+            )
 
             # Only update badge if we have valid coverage data
             if current_coverage is not None and current_coverage >= 0:
@@ -410,13 +428,12 @@ class TestManager:
 
     async def run_pre_test_lsp_diagnostics(self) -> bool:
         """Run LSP diagnostics before tests to catch type errors early."""
-        if not self.use_lsp_diagnostics:
+        if not self.use_lsp_diagnostics or self._lsp_client is None:
             return True
 
         try:
-            from crackerjack.services.lsp_client import LSPClient
-
-            lsp_client = LSPClient(self.console)
+            # Use injected LSP client (already instantiated)
+            lsp_client = self._lsp_client
 
             # Check if LSP server is available
             if not lsp_client.is_server_running():
