@@ -4,6 +4,7 @@ from .intelligence_tool_registry import register_intelligence_tools
 from .monitoring_tools import register_monitoring_tools
 from .proactive_tools import register_proactive_tools
 from .progress_tools import register_progress_tools
+from .semantic_tools import register_semantic_tools
 from .utility_tools import register_utility_tools
 
 __all__ = [
@@ -13,5 +14,6 @@ __all__ = [
     "register_monitoring_tools",
     "register_progress_tools",
     "register_proactive_tools",
+    "register_semantic_tools",
     "register_utility_tools",
 ]
