@@ -13,16 +13,23 @@ async def execute_crackerjack_workflow(
 ) -> dict[str, t.Any]:
     job_id = str(uuid.uuid4())[:8]
 
+    # Get context first
+    context = get_context()
+
     # Initialize progress immediately
-    await _update_progress(
+    _update_progress(
         job_id,
         {"status": "started", "args": args, "timestamp": time.time()},
+        context,
+        1,
+        5,
         0,
-        message="Crackerjack execution started",
+        "initialization",
+        0,
+        "Crackerjack execution started",
     )
 
     # Start execution in background - no timeout!
-    context = get_context()
     asyncio.create_task(_execute_crackerjack_background(job_id, args, kwargs, context))
 
     # Return job_id immediately for progress monitoring
@@ -45,7 +52,7 @@ async def _execute_crackerjack_background(
         result = await _execute_crackerjack_sync(job_id, args, kwargs, context)
 
         # Update final progress with result
-        await _update_progress(
+        _update_progress(
             job_id,
             {
                 "status": result.get("status", "completed"),
@@ -53,14 +60,19 @@ async def _execute_crackerjack_background(
                 "timestamp": time.time(),
                 "final": True,
             },
+            context,
+            1,
+            5,
             100,
-            message=f"Execution {result.get('status', 'completed')}",
+            "completed",
+            100,
+            f"Execution {result.get('status', 'completed')}",
         )
     except Exception as e:
         import traceback
 
         # Update progress with error
-        await _update_progress(
+        _update_progress(
             job_id,
             {
                 "status": "failed",
@@ -69,8 +81,13 @@ async def _execute_crackerjack_background(
                 "timestamp": time.time(),
                 "final": True,
             },
+            context,
+            1,
+            5,
             -1,
-            message=f"Execution failed: {e}",
+            "failed",
+            -1,
+            f"Execution failed: {e}",
         )
 
 
@@ -188,12 +205,8 @@ async def _create_advanced_orchestrator(
     from pathlib import Path
 
     from crackerjack.core.async_workflow_orchestrator import AsyncWorkflowOrchestrator
-    from crackerjack.core.enhanced_container import EnhancedDependencyContainer
-
-    container = EnhancedDependencyContainer()
-
-    await _register_core_services(container, Path(working_dir))
 
+    # AsyncWorkflowOrchestrator now uses ACB DI internally
     orchestrator = AsyncWorkflowOrchestrator(
         pkg_path=Path(working_dir),
         verbose=kwargs.get("verbose", False),
@@ -214,7 +227,7 @@ def _create_standard_orchestrator(
 
 
 async def _register_core_services(container: t.Any, working_dir: t.Any) -> None:
-    from rich.console import Console
+    from acb.console import Console
 
     from crackerjack.managers.hook_manager import AsyncHookManager
     from crackerjack.managers.publish_manager import PublishManagerImpl
@@ -227,7 +240,7 @@ async def _register_core_services(container: t.Any, working_dir: t.Any) -> None:
     )
     from crackerjack.services.enhanced_filesystem import EnhancedFileSystemService
 
-    console = Console()
+    console = depends.get_sync(Console)
 
     container.register_singleton(
         HookManager,
@@ -239,9 +252,11 @@ async def _register_core_services(container: t.Any, working_dir: t.Any) -> None:
         factory=lambda: TestManagementImpl(console, working_dir),
     )
 
+    # Use factory without parameters to trigger @depends.inject decorator
+    # The decorator will inject all dependencies from the DI container
     container.register_singleton(
         PublishManager,
-        factory=lambda: PublishManagerImpl(console, working_dir),
+        factory=lambda: PublishManagerImpl(),
     )
 
     container.register_singleton(
@@ -419,43 +434,69 @@ async def _execute_single_iteration(
     context: t.Any,
 ) -> bool:
     try:
-        if hasattr(orchestrator, "run_complete_workflow_async"):
-            result = orchestrator.run_complete_workflow_async(options)
-            if result is None:
-                raise ValueError(
-                    "Method run_complete_workflow_async returned None instead of awaitable"
-                )
-            workflow_result: bool = await result
-            return workflow_result
-        elif hasattr(orchestrator, "run_complete_workflow"):
-            result = orchestrator.run_complete_workflow(options)
-            if result is None:
-                raise ValueError(
-                    "Method run_complete_workflow returned None instead of awaitable"
-                )
-            workflow_result: bool = await result
-            return workflow_result
-        elif hasattr(orchestrator, "execute_workflow"):
-            result = orchestrator.execute_workflow(options)
-            if result is None:
-                raise ValueError(
-                    "Method execute_workflow returned None instead of awaitable"
-                )
-            workflow_result: bool = await result
-            return workflow_result
-        elif hasattr(orchestrator, "run"):
-            run_result: bool = orchestrator.run(options)
-            return run_result
-        else:
-            raise ValueError(
-                f"Orchestrator {type(orchestrator)} has no recognized workflow execution method"
-            )
+        method_name = _detect_orchestrator_method(orchestrator)
+        result = _invoke_orchestrator_method(orchestrator, method_name, options)
+
+        # Sync methods return directly, async methods need await
+        if method_name == "run":
+            return result
+
+        # Async methods - validate and await
+        _validate_awaitable_result(result, method_name, orchestrator)
+        return await result
     except Exception as e:
         raise RuntimeError(
             f"Error in _execute_single_iteration (iteration {iteration}): {e}"
         ) from e
 
 
+def _detect_orchestrator_method(orchestrator: t.Any) -> str:
+    """Detect which workflow method the orchestrator supports."""
+    method_priority = [
+        "run_complete_workflow_async",
+        "run_complete_workflow",
+        "execute_workflow",
+        "run",
+    ]
+
+    for method_name in method_priority:
+        if hasattr(orchestrator, method_name):
+            return method_name
+
+    available_methods = [m for m in dir(orchestrator) if not m.startswith("_")]
+    raise ValueError(
+        f"Orchestrator {type(orchestrator).__name__} has no recognized workflow execution method. "
+        f"Available methods: {available_methods}"
+    )
+
+
+def _invoke_orchestrator_method(
+    orchestrator: t.Any, method_name: str, options: t.Any
+) -> t.Any:
+    """Invoke the detected orchestrator method with options."""
+    method = getattr(orchestrator, method_name)
+    result = method(options)
+
+    if result is None:
+        raise ValueError(
+            f"Method {method_name} returned None instead of expected result. "
+            f"Orchestrator type: {type(orchestrator).__name__}"
+        )
+
+    return result
+
+
+def _validate_awaitable_result(
+    result: t.Any, method_name: str, orchestrator: t.Any
+) -> None:
+    """Validate that async method result is awaitable."""
+    if not hasattr(result, "__await__"):
+        raise ValueError(
+            f"Method {method_name} returned non-awaitable object: {type(result).__name__}. "
+            f"Orchestrator: {type(orchestrator).__name__}"
+        )
+
+
 def _create_success_result(
     job_id: str,
     iterations: int,
