@@ -8,15 +8,13 @@ import typing as t
 from pathlib import Path
 
 import uvicorn
-from rich.console import Console
+from acb import console
 
 from crackerjack.core.timeout_manager import get_timeout_manager
 
 from .app import create_websocket_app
 from .jobs import JobManager
 
-console = Console()
-
 
 class WebSocketServer:
     def __init__(self, port: int = 8675) -> None:
