@@ -1,7 +1,8 @@
 from contextlib import suppress
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
+from acb.depends import Inject, depends
 
 from .regex_patterns import SAFE_PATTERNS
 
@@ -9,7 +10,8 @@ from .regex_patterns import SAFE_PATTERNS
 class CoverageBadgeService:
     """Service for managing coverage badges in README.md files."""
 
-    def __init__(self, console: Console, project_root: Path) -> None:
+    @depends.inject
+    def __init__(self, console: Inject[Console], project_root: Path) -> None:
         self.console = console
         self.project_root = project_root
         self.readme_path = project_root / "README.md"
