@@ -1,8 +1,11 @@
-import subprocess
+import subprocess  # nosec B404
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
+from acb.depends import Inject, depends
+
+from crackerjack.models.protocols import GitInterface
 
 from .secure_subprocess import execute_secure_subprocess
 from .security_logger import get_security_logger
@@ -31,8 +34,9 @@ class FailedGitResult:
         self.stderr = f"Git security validation failed: {error}"
 
 
-class GitService:
-    def __init__(self, console: Console, pkg_path: Path | None = None) -> None:
+class GitService(GitInterface):
+    @depends.inject
+    def __init__(self, console: Inject[Console], pkg_path: Path | None = None) -> None:
         self.console = console
         self.pkg_path = pkg_path or Path.cwd()
 
@@ -156,7 +160,7 @@ class GitService:
 
     def _retry_commit_after_restage(self, message: str) -> bool:
         self.console.print(
-            "[yellow]🔄[/ yellow] Pre - commit hooks modified files - attempting to re-stage and retry commit"
+            "[yellow]🔄[/yellow] Pre-commit hooks modified files - attempting to re-stage and retry commit"
         )
 
         add_result = self._run_git_command(GIT_COMMANDS["add_updated"])
