@@ -1,4 +1,4 @@
-def test_handle_error_basic(self):
+def test_handle_error_basic():
     """Test basic functionality of handle_error."""
     try:
         result = handle_error()
@@ -10,7 +10,7 @@ def test_handle_error_basic(self):
     except Exception as e:
         pytest.fail(f"Unexpected error in handle_error: {e}")
 
-def test_check_file_exists_basic(self):
+def test_check_file_exists_basic():
     """Test basic functionality of check_file_exists."""
     try:
         result = check_file_exists()
@@ -22,7 +22,7 @@ def test_check_file_exists_basic(self):
     except Exception as e:
         pytest.fail(f"Unexpected error in check_file_exists: {e}")
 
-def test_check_command_result_basic(self):
+def test_check_command_result_basic():
     """Test basic functionality of check_command_result."""
     try:
         result = check_command_result()
@@ -34,7 +34,7 @@ def test_check_command_result_basic(self):
     except Exception as e:
         pytest.fail(f"Unexpected error in check_command_result: {e}")
 
-def test_format_error_report_basic(self):
+def test_format_error_report_basic():
     """Test basic functionality of format_error_report."""
     try:
         result = format_error_report()
